← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~tomasgroth/openlp/packaging-win-fix into lp:openlp/packaging

 

Tomas Groth has proposed merging lp:~tomasgroth/openlp/packaging-win-fix into lp:openlp/packaging.

Requested reviews:
  OpenLP Core (openlp-core)

For more details, see:
https://code.launchpad.net/~tomasgroth/openlp/packaging-win-fix/+merge/281485

Update windows building for qt5.
-- 
Your team OpenLP Core is requested to review the proposed merge of lp:~tomasgroth/openlp/packaging-win-fix into lp:openlp/packaging.
=== modified file 'windows/config.ini.default'
--- windows/config.ini.default	2014-09-02 13:07:50 +0000
+++ windows/config.ini.default	2016-01-03 21:15:43 +0000
@@ -5,10 +5,10 @@
 vcbuild = %(progfiles)s\Microsoft Visual Studio 9.0\VC\vcpackages\vcbuild.exe
 htmlhelp = %(progfiles)s\HTML Help Workshop\hhc.exe
 psvince = %(here)s\psvince.dll
-lrelease = %(sitepackages)s\PyQt4\bin\lrelease.exe
+lrelease = %(sitepackages)s\PyQt5\bin\lrelease.exe
 portablelauncher = %(progfiles)s\PortableApps.comLauncher\PortableApps.comLauncherGenerator.exe
 portableinstaller = %(progfiles)s\PortableApps.comInstaller\PortableApps.comInstaller.exe
-mudrawbin = %(here)s\..\mupdf-1.5-windows\mudraw.exe
+mudrawbin = %(here)s\..\mupdf-1.8-windows\mudraw.exe
 
 [paths]
 branch = %(projects)s\trunk

=== modified file 'windows/windows-builder.py' (properties changed: -x to +x)
--- windows/windows-builder.py	2015-12-23 17:16:13 +0000
+++ windows/windows-builder.py	2016-01-03 21:15:43 +0000
@@ -27,9 +27,9 @@
 This script is used to build the Windows binary and the accompanying installer.
 For this script to work out of the box, it depends on a number of things:
 
-Python 3.3/3.4
+Python 3.4
 
-PyQt4
+PyQt5
     You should already have this installed, OpenLP doesn't work without it. The
     version the script expects is the packaged one available from River Bank
     Computing.
@@ -213,14 +213,14 @@
         self.portableinstaller = os.path.abspath(self.config.get('executables', 'portableinstaller'))
         self.portablelauncher = os.path.abspath(self.config.get('executables', 'portablelauncher'))
         self.mudraw_bin = os.path.abspath(self.config.get('executables', 'mudrawbin'))
-        if os.path.exists(os.path.join(self.site_packages, 'PyQt4', 'bin')):
-            # Older versions of the PyQt4 Windows installer put their binaries
+        if os.path.exists(os.path.join(self.site_packages, 'PyQt5', 'bin')):
+            # Older versions of the PyQt5 Windows installer put their binaries
             # in the "bin" directory
-            self.lrelease = os.path.join(self.site_packages, 'PyQt4', 'bin', 'lrelease.exe')
+            self.lrelease = os.path.join(self.site_packages, 'PyQt5', 'bin', 'lrelease.exe')
         else:
             # Newer versions of the PyQt4 Windows installer put their binaries
             # in the base directory of the installation
-            self.lrelease = os.path.join(self.site_packages, 'PyQt4', 'lrelease.exe')
+            self.lrelease = os.path.join(self.site_packages, 'PyQt5', 'lrelease.exe')
 
     def setup_paths(self):
         """
@@ -448,7 +448,7 @@
                 if code != 0:
                     raise Exception('Error running lconvert on %s' % source_path)
         self._print('Copying qm files...')
-        source = os.path.join(self.site_packages, 'PyQt4', 'translations')
+        source = os.path.join(self.site_packages, 'PyQt5', 'translations')
         files = os.listdir(source)
         for filename in files:
             if filename.startswith('qt_') and filename.endswith('.qm') and len(filename) == 8:
@@ -213,14 +213,14 @@
         else:
-            # Newer versions of the PyQt4 Windows installer put their binaries
+            # Newer versions of the PyQt5 Windows installer put their binaries
             # in the base directory of the installation


Follow ups